@@ -44,23 +44,23 @@ void Cache::expire(LinkedObject **root, LinkedObject **freelist)
 {
     Cache *prior = NULL;
     Cache *node = (Cache *)*root;
-    Cache *next;
+    Cache *after;
     time_t now;
 
     time(&now);
 
     while(node) {
-        next = (Cache *)node->next;
+        after = (Cache *)node->Next;
         if(node->expires && now > node->expires) {
             if(!prior)
-                *root = next;
+                *root = after;
             else
-                prior->next = next;
+                prior->Next = after;
             node->enlist(freelist);
         }
         else
             prior = node;
-        node = next;
+        node = after;
     }
 }
 
@@ -96,7 +96,7 @@ void cache::userdump(void)
         linked_pointer<UserCache> up = user_keys[i];
         while(is(up)) {
             if(!up->expires || up->expires > now) {
-                Socket::getaddress((struct sockaddr *)(&up->address), buffer, sizeof(buffer));
+                Socket::query((struct sockaddr *)(&up->address), buffer, sizeof(buffer));
                 if(up->expires)
                     fprintf(fp, "%s=%s; expires=%ld\n",
                         up->userid, buffer, (long)(up->expires - now));
@@ -170,7 +170,7 @@ void UserCache::add(const char *id, struct sockaddr *addr, time_t create, unsign
 
     if(user_freelist) {
         cp = (UserCache *)user_freelist;
-        user_freelist = cp->next;
+        user_freelist = cp->Next;
     }
     else {
         caddr_t mp = (caddr_t)cache_heap.alloc(sizeof(UserCache));
