@@ -43,26 +43,33 @@ class __EXPORT voip
 public:
 	#ifdef  EXOSIP_API4
 	typedef eXosip_t    *context_t;
-	inline  void lock(context_t ctx) {eXosip_lock(ctx);}
-	inline  void unlock(context_t ctx) {eXosip_unlock(ctx);}
+	inline  static void lock(context_t ctx) {eXosip_lock(ctx);}
+	inline  static void unlock(context_t ctx) {eXosip_unlock(ctx);}
 	#else
 	typedef void        *context_t;
-	inline  void lock(context_t ctx) {eXosip_lock();}
-	inline  void unlock(context_t ctx) {eXosip_unlock();}
+	inline  static void lock(context_t ctx) {eXosip_lock();}
+	inline  static void unlock(context_t ctx) {eXosip_unlock();}
 	#endif
 
-	typedef eXosip_event_t  *event_t;
-	typedef int reg_t;		// registration id
-	typedef	int	tid_t;		// transaction id
-	typedef	int did_t;		// dialog id
-	typedef	int	call_t;		// call id
-	typedef	osip_header_t	*hdr_t;
-	typedef	osip_message_t	*msg_t;
-	typedef	osip_from_t		*from_t;
-	typedef	osip_via_t		*via_t;
-	typedef	osip_to_t		*to_t;
-	typedef	osip_uri_t		*uri_t;
-	typedef	unsigned long timeout_t;
+	typedef eXosip_event_t		*event_t;
+	typedef int reg_t;			// registration id
+	typedef	int	tid_t;			// transaction id
+	typedef	int did_t;			// dialog id
+	typedef	int	call_t;			// call id
+	typedef	osip_header_t		*hdr_t;
+	typedef	osip_message_t		*msg_t;
+	typedef	osip_contact_t		*contact_t;
+	typedef	osip_uri_param_t	*uri_param_t;
+	typedef osip_body_t			*body_t;
+	typedef	osip_content_type_t	*ctype_t;
+	typedef	osip_from_t			*from_t;
+	typedef	osip_via_t			*via_t;
+	typedef	osip_to_t			*to_t;
+	typedef	osip_uri_t			*uri_t;
+	typedef	unsigned long		timeout_t;
+	typedef osip_authorization_t		*auth_t;
+	typedef	osip_generic_param_t		*param_t;
+	typedef	osip_proxy_authenticate_t	*proxyauth_t;
 
 	static bool make_request_message(context_t ctx, const char *method, const char *to, const char *from, msg_t *msg, const char *route = NULL);
 	static bool make_response_message(context_t ctx, tid_t tid, int status, msg_t *msg);
@@ -109,6 +116,7 @@ public:
 	static void call_reference(context_t ctx, call_t cid, void *route);
 	static void free_message_request(context_t ctx, voip::msg_t msg);
 	static void release_event(event_t ev);
+	static void option(context_t ctx, int opt, const void *value);
 
 	static bool listen(context_t ctx, int proto = IPPROTO_UDP, const char *iface = NULL, unsigned port = 5060, bool tls = false);
 	static void create(context_t *ctx, const char *agent, int family = AF_INET);
