@@ -25,18 +25,6 @@
 
 #include <ctype.h>
 
-#ifdef  EXOSIP_API4
-#define EXOSIP_CONTEXT  stack::sip.out_context
-#define OPTION_CONTEXT  stack::sip.out_context,
-#define EXOSIP_LOCK     eXosip_lock(stack::sip.out_context);
-#define EXOSIP_UNLOCK   eXosip_unlock(stack::sip.out_context);
-#else
-#define EXOSIP_CONTEXT
-#define OPTION_CONTEXT
-#define EXOSIP_LOCK     eXosip_lock();
-#define EXOSIP_UNLOCK   eXosip_unlock();
-#endif
-
 #define P_SIPWITCH_NODE "P-sipwitch-node"
 
 #define SECOND_TIMEOUT  (1000l)
@@ -373,7 +361,7 @@ private:
     void snapshot(FILE *fp);
     bool check(void);
 
-    static void divert(stack::call *cr, osip_message_t *msg);
+    static void divert(stack::call *cr, voip::msg_t msg);
 
     unsigned threading, priority;
     size_t stacksize;
@@ -442,18 +430,18 @@ public:
     static void detach(session *s);
     static void clear(session *s);
     static void close(session *s);
-    static session *access(int cid);
+    static session *access(voip::call_t cid);
     static char *sipAddress(struct sockaddr_internet *addr, char *buf, const char *user = NULL, size_t size = MAX_URI_SIZE);
     static char *sipPublish(struct sockaddr_internet *addr, char *buf, const char *user = NULL, size_t size = MAX_URI_SIZE);
     static char *sipContact(struct sockaddr_internet *addr, char *buf, const char *user = NULL, const char *display = NULL, size_t size = MAX_URI_SIZE);
     static Socket::address *getAddress(const char *uri, Socket::address *addr = NULL);
-    static void siplog(osip_message_t *msg);
+    static void siplog(voip::msg_t msg);
     static void enableDumping(void);
     static void clearDumping(void);
     static void disableDumping(void);
-    static void refer(session *session, eXosip_event_t *sevent);
-    static void infomsg(session *session, eXosip_event_t *sevent);
-    static void setDialog(session *session, int did);
+    static void refer(session *session, voip::event_t sevent);
+    static void infomsg(session *session, voip::event_t sevent);
+    static void setDialog(session *session, voip::did_t did);
     static int getDialog(session *session);
     static void release(MappedCall *map);
     static MappedCall *get(void);
@@ -524,8 +512,8 @@ public:
     static void activate(MappedRegistry *rr);
     static void expire(MappedRegistry *rr);
     static void logging(MappedRegistry *rr, const char *reason);
-    static void registration(int id, modules::regmode_t mode);
-    static bool authenticate(int id, const char *realm);
+    static void registration(voip::reg_t id, modules::regmode_t mode);
+    static bool authenticate(voip::reg_t id, const char *realm);
     static const char *resolve(const char *uri, struct sockaddr_storage *addr);
     static const char *referLocal(MappedRegistry *rr, const char *target, char *buffer, size_t size);
     static const char *referRemote(MappedRegistry *rr, const char *target, char *buffer, size_t size);
@@ -539,7 +527,6 @@ private:
     class __LOCAL message : public LinkedObject
     {
     public:
-        voip::context_t context;
         time_t expires;
         char user[MAX_USERID_SIZE];
         char type[64];
@@ -611,8 +598,8 @@ private:
     voip::context_t context;
 
     char *sip_realm;
-    osip_proxy_authenticate_t *proxy_auth;
-    osip_www_authenticate_t *www_auth;
+    voip::proxyauth_t proxy_auth;
+    voip::proxyauth_t www_auth;
 
     enum {CALL, MESSAGE, REGISTRAR, NONE} authorizing;
 
