@@ -308,7 +308,7 @@ void stack::enableDumping(void)
     stack::sip.dumping = true;
 }
 
-void stack::siplog(osip_message_t *msg)
+void stack::siplog(voip::msg_t msg)
 {
     fsys_t log;
     char *text = NULL;
@@ -397,7 +397,7 @@ void stack::clear(session *s)
             cr->source->sequence, cr->source->cid, s->sequence, s->cid);
         if(s->state != session::CLOSED) {
             s->state = session::CLOSED;
-            eXosip_call_terminate(OPTION_CONTEXT s->cid, s->did);
+            voip::release_call(s->context, s->cid, s->did);
         }
         s->delist(&hash[s->cid % keysize]);
         s->cid = 0;
@@ -418,7 +418,7 @@ void stack::destroy(session *s)
     destroy(s->parent);
 }
 
-void stack::setDialog(session *s, int did)
+void stack::setDialog(session *s, voip::did_t did)
 {
     assert(s != NULL && s->parent != NULL);
     Mutex::protect(s->parent);
@@ -428,7 +428,7 @@ void stack::setDialog(session *s, int did)
 
 int stack::getDialog(session *s)
 {
-    int did = -1;
+    voip::did_t did = -1;
 
     if(s && s->parent) {
         Mutex::protect(s->parent);
@@ -438,16 +438,16 @@ int stack::getDialog(session *s)
     return did;
 }
 
-void stack::refer(session *source, eXosip_event_t *sevent)
+void stack::refer(session *source, voip::event_t sevent)
 {
     assert(source);
     assert(sevent);
 
-    osip_header_t *header = NULL;
-    osip_message_t *msg = NULL;
+    voip::hdr_t header = NULL;
+    voip::msg_t msg = NULL;
     session *target = NULL;
     call *cr = source->parent;
-    int did;
+    voip::did_t did;
 
     if(cr->source == source)
         target = cr->target;
@@ -474,15 +474,15 @@ failed:
     target->tid = sevent->tid;
 }
 
-void stack::infomsg(session *source, eXosip_event_t *sevent)
+void stack::infomsg(session *source, voip::event_t sevent)
 {
     assert(source);
     assert(sevent);
 
     char type[128];
-    osip_content_type_t *ct;
-    osip_message_t *msg = NULL;
-    osip_body_t *body = NULL;
+    voip::ctype_t ct;
+    voip::msg_t msg = NULL;
+    voip::body_t body = NULL;
     session *target = NULL;
     call *cr = source->parent;
 
@@ -491,7 +491,7 @@ void stack::infomsg(session *source, eXosip_event_t *sevent)
     else if(cr->target == source)
         target = cr->source;
 
-    int did = getDialog(target);
+    voip::did_t did = getDialog(target);
     if(did < 1)
         return;
 
@@ -524,9 +524,7 @@ void stack::disjoin(call *cr)
                 s->closed = true;
             }
             if(s->cid > 0 && s->state != session::CLOSED) {
-                EXOSIP_LOCK
-                eXosip_call_terminate(OPTION_CONTEXT s->cid, s->did);
-                EXOSIP_UNLOCK
+                voip::release_call(s->context, s->cid, s->did);
                 s->state = session::CLOSED;
             }
         }
@@ -561,9 +559,7 @@ void stack::destroy(call *cr)
 
         if(sp->sid.cid > 0) {
             if(sp->sid.state != session::CLOSED) {
-                EXOSIP_LOCK
-                eXosip_call_terminate(OPTION_CONTEXT sp->sid.cid, sp->sid.did);
-                EXOSIP_UNLOCK
+                voip::release_call(sp->sid.context, sp->sid.cid, sp->sid.did);
             }
             sp->sid.delist(&hash[sp->sid.cid % keysize]);
         }
@@ -668,7 +664,7 @@ stack::session *stack::create(voip::context_t context, voip::call_t cid, voip::d
     return cr->source;
 }
 
-stack::session *stack::access(int cid)
+stack::session *stack::access(voip::call_t cid)
 {
     assert(cid > 0);
 
@@ -712,9 +708,6 @@ void stack::start(service *cfg)
 
     tcp_context = udp_context = tls_context = out_context = NULL;
 
-#ifdef  EXOSIP_API4
-    sip.out_context = eXosip_malloc();
-#endif
     mapped_array<MappedCall>::create(control::env("callmap"), mapped_calls);
     if(!sip)
         shell::log(shell::FAIL, "calls could not be mapped");
@@ -818,9 +811,21 @@ void stack::stop(service *cfg)
 
 bool stack::check(void)
 {
-    shell::log(shell::INFO, "checking sip stack...");
-    EXOSIP_LOCK
-    EXOSIP_UNLOCK
+    if(tcp_context) {
+        shell::log(shell::INFO, "checking tcp context...");
+        voip::lock(tcp_context);
+        voip::unlock(tcp_context);
+    }
+    if(udp_context) {
+        shell::log(shell::INFO, "checking udp context...");
+        voip::lock(udp_context);
+        voip::unlock(udp_context);
+    }
+    if(tls_context) {
+        shell::log(shell::INFO, "checking tls context...");
+        voip::lock(tls_context);
+        voip::unlock(tls_context);
+    }
     return true;
 }
 
@@ -901,11 +906,11 @@ void stack::reload(service *cfg)
                 send101 = 0;
             else if(eq(key, "keepalive") && !is_configured()) {
                 val = atoi(value);
-                eXosip_set_option(OPTION_CONTEXT EXOSIP_OPT_UDP_KEEP_ALIVE, &val);
+                voip::option(udp_context, EXOSIP_OPT_UDP_KEEP_ALIVE, &val);
             }
             else if(eq(key, "learn") && !is_configured()) {
                 val = tobool(value);
-                eXosip_set_option(OPTION_CONTEXT EXOSIP_OPT_UDP_LEARN_PORT, &val);
+                voip::option(udp_context, EXOSIP_OPT_UDP_LEARN_PORT, &val);
             }
             else if(eq(key, "restricted")) {
                 if(eq(value, "none"))
@@ -1190,7 +1195,7 @@ set:
     return ap;
 }
 
-void stack::divert(stack::call *call, osip_message_t *invite)
+void stack::divert(stack::call *call, voip::msg_t invite)
 {
     char route[MAX_URI_SIZE];
     char touri[MAX_URI_SIZE];
@@ -1235,7 +1240,7 @@ int stack::inviteRemote(stack::session *s, const char *uri_target, const char *d
     char network[MAX_NETWORK_SIZE];
     char touri[MAX_URI_SIZE];
     char route[MAX_URI_SIZE];
-    osip_message_t *invite = NULL;
+    voip::msg_t invite = NULL;
     char expheader[32];
     char seqid[64];
     int cid;
@@ -1521,7 +1526,7 @@ int stack::inviteLocal(stack::session *s, registry::mapped *rr, destination_t de
     char sdp[MAX_SDP_BUFFER];
 
     time_t now;
-    osip_message_t *invite;
+    voip::msg_t invite;
     char expheader[32];
     char seqid[64];
     char route[MAX_URI_SIZE];
